@@ -12,6 +12,7 @@ __all__ = [
     "hotpotqa",
     "smcalflow",
     "xtreme",
+    "ogb",
 ]
 
 
@@ -28,3 +29,4 @@ from sota_extractor.scrapers.record import record
 from sota_extractor.scrapers.hotpotqa import hotpotqa
 from sota_extractor.scrapers.smcalflow import smcalflow
 from sota_extractor.scrapers.xtreme import xtreme
+from sota_extractor.scrapers.ogb import ogb
