@@ -66,7 +66,7 @@ def smcalflow() -> TaskDB:
     except Exception as e:
         raise HttpClientError(message=str(e))
 
-    dataset = Dataset(name=DATASET_NAME, is_subdataset=False,)
+    dataset = Dataset(name=DATASET_NAME, is_subdataset=False)
     task = Task(name=TASK_NAME)
     task.datasets = [dataset]
     task.source_link = Link(title="SMCalFlow Leaderboard", url=URL)
